@@ -42,13 +42,19 @@ class RestAPI(object):
 			"api_key":None,
 			# the subscription plan.
 			"membership":"free",
-			# the requests variables.
-			"requests":0,
-			"timestamp":None,
-			# the signed up timestamp.
-			"signed_up":None,
-			# the email permission,
-			"email_permission":True,
+			# the timestamps.
+			"timestamps": {
+				"signed_up":None,
+			}
+			# the requests.
+			"requests": {
+				"rate":0,
+				"timestamp":0,
+			}
+			# the permissions,
+			"permissions": {
+				"email":True,
+			},
 		}
 
 		"""
@@ -477,7 +483,7 @@ class RestAPI(object):
 		response = self.firebase.users.load_data(uid)
 		if response["error"] != None: return response
 		data = response["data"]
-		timestamp = response["data"]["timestamp"]
+		timestamp = response["data"]["requests"]["timestamp"]
 		date = Formats.Date()
 
 		# check trial.
@@ -488,15 +494,15 @@ class RestAPI(object):
 		success = False
 		if timestamp == None:
 			success = True
-			data["timestamp"] = date.date
-			data["requests"] = 0
+			data["requests"]["timestamp"] = date.date
+			data["requests"]["rate"] = 0
 		else:
 			altered = date.increase(timestamp, days=self.__plans__[plan]["rate_reset"], format="%d-%m-%y")
 			#decreased_timestamp = date.from_seconds(decreased)
 			if date.compare(altered, date.date, format="%d-%m-%y") in ["present", "past"]:
 				success = True
-				data["timestamp"] = date.date
-				data["requests"] = 0
+				data["requests"]["timestamp"] = date.date
+				data["requests"]["rate"] = 0
 
 			# check rate limit.
 			if not success and int(data["requests"]) <= self.__plans__[plan]["rate_limit"]: 
@@ -504,7 +510,7 @@ class RestAPI(object):
 
 		# response.
 		if success:
-			data["requests"] += 1
+			data["requests"]["rate"] += 1
 			response = self.firebase.users.save_data(uid, data)
 			if response["error"] != None: return response
 			return r3sponse.success_response("Successfully verified the rate limit.")
@@ -526,8 +532,8 @@ class RestAPI(object):
 		data = response["document"]
 
 		# edit data.
-		data["requests"] = -1*requests
-		data["timestamp"] = Formats.Date().date
+		data["requests"]["rate"] = -1*requests
+		data["requests"]["timestamp"] = Formats.Date().date
 
 		# save data.
 		response = self.firebase.firestore.save(reference, data) 
@@ -546,8 +552,8 @@ class RestAPI(object):
 		data = response["document"]
 
 		# edit data.
-		data["requests"] = 0
-		data["timestamp"] = Formats.Date().date
+		data["requests"]["rate"] = 0
+		data["requests"]["timestamp"] = Formats.Date().date
 
 		# save data.
 		response = self.firebase.firestore.save(reference, data) 
